define(
//begin v1.x content
({
	"descTemplate": "${2} - ${3} מתוך ${1} ${0}",
	"firstTip": "עמוד ראשון",
	"lastTip": "עמוד אחרון",
	"nextTip": "העמוד הבא",
	"prevTip": "העמוד הקודם",
	"itemTitle": "פריטים",
	"pageStepLabelTemplate": "עמוד ${0}",
	"pageSizeLabelTemplate": "${0} פריטים לעמוד",
	"allItemsLabelTemplate": "כל הפריטים",
	"gotoButtonTitle": "מעבר לעמוד ספציפי",
	"dialogTitle": "מעבר לעמוד",
	"dialogIndication": "ציון מספר העמוד",
	"pageCountIndication": " (${0} עמודים)",
	"dialogConfirm": "ביצוע",
	"dialogCancel": "ביטול",
	"all": "הכל"
})
//end v1.x content
);

